// -*- c++ -*-

/*
 *  Author: Arvin Schnell
 */


#ifndef pcm_h
#define pcm_h


class PCM
{

public:

    enum pcm_mode_t { PLAY, RECORD };
    enum pcm_format_t { S8, S16, S32 };

    static PCM* create (const char* name, pcm_mode_t mode, pcm_format_t format,
			int channels, int rate, int buffer_size);

    virtual ~PCM ();

    virtual void info () = 0;

    virtual bool read (void* buffer, int frames) = 0;
    virtual bool write (void* buffer, int frames) = 0;

    int get_bytes_per_frame () const { return channels * (1 << format); }
    int get_buffer_size () const { return buffer_size; }

    void swap_buffer (void* buffer, int frames);

    static void swap_buffer (void* buffer, int frames, pcm_format_t format,
			     int channels);

protected:

    PCM (const char* name, pcm_mode_t mode, pcm_format_t format,
	 int channels, int rate, int buffer_size);

    bool ok;

    char* name;
    pcm_mode_t mode;
    pcm_format_t format;
    int channels;
    int rate;

    int buffer_size;

};


#endif
